@@ -52,7 +52,7 @@
 */
 
 #ifndef gmic_version
-#define gmic_version 299
+#define gmic_version 302
 
 #ifndef gmic_pixel_type
 #define gmic_pixel_type float
@@ -74,7 +74,11 @@
 #endif // #if cimg_OS==2
 #endif // #ifndef gmic_uint64
 
-#ifndef gmic_build
+// Define some special character codes used for replacement in double quoted strings.
+const char gmic_dollar = 23, gmic_lbrace = 24, gmic_rbrace = 25, gmic_comma = 26, gmic_dquote = 28,
+  gmic_store = 29; // <- this one is only used in variable names.
+
+#ifndef gmic_core
 
 // Define classes 'gmic_image<T>' and 'gmic_list<T>'.
 //---------------------------------------------------
@@ -173,7 +177,7 @@ namespace cimg_library {
 #undef gmic_list
 #endif // #ifndef cimg_version
 
-#else // #ifndef gmic_build
+#else // #ifndef gmic_core
 
 // Define private functions, used to compile libgmic.
 //---------------------------------------------------
@@ -191,12 +195,16 @@ namespace cimg_library {
 #ifdef cimg_version
 #error "[gmic] *** Error *** File 'CImg.h' has been already included (should have been done first in file 'gmic.h')."
 #endif
+#ifndef cimg_plugin
 #define cimg_plugin "gmic.cpp"
+#endif
+#ifndef cimglist_plugin
 #define cimglist_plugin "gmic.cpp"
+#endif
 
 #ifdef cimg_use_abort
 inline bool *gmic_abort_ptr(bool *const p_is_abort);
-#define cimg_abort_init bool *const gmic_is_abort = ::gmic_abort_ptr(0)
+#define cimg_abort_init bool *const gmic_is_abort = ::gmic_abort_ptr(0); cimg::unused(gmic_is_abort)
 #define cimg_abort_test if (*gmic_is_abort) throw CImgAbortException()
 #endif
 
@@ -204,31 +212,31 @@ template<typename T>
 inline double gmic_mp_dollar(const char *const str,
                              void *const p_list, const T& pixel_type);
 #define cimg_mp_operator_dollar(str) \
-  ::gmic_mp_dollar(str,&listout,(T)0)
+  ::gmic_mp_dollar(str,&imglist,(T)0)
 
 template<typename Ts, typename T>
 inline double gmic_mp_get(Ts *const ptr, const unsigned int siz, const bool to_string, const char *const str,
                           void *const p_list, const T& pixel_type);
 #define cimg_mp_func_get(ptr,siz,to_string,str) \
-  return ::gmic_mp_get(ptr,siz,to_string,str,&mp.listout,(T)0)
+  return ::gmic_mp_get(ptr,siz,to_string,str,&mp.imglist,(T)0)
 
 template<typename Ts, typename T>
 inline double gmic_mp_set(Ts *const ptr, const unsigned int siz, const char *const str,
                           void *const p_list, const T& pixel_type);
 #define cimg_mp_func_set(ptr,siz,str) \
-  return ::gmic_mp_set(ptr,siz,str,&mp.listout,(T)0)
+  return ::gmic_mp_set(ptr,siz,str,&mp.imglist,(T)0)
 
 template<typename T, typename Ts>
 inline double gmic_mp_name(const unsigned int ind, Ts *const out_str, const unsigned int siz,
                            void *const p_list, const T& pixel_type);
 #define cimg_mp_func_name(ind,out_str,siz) \
-  return ::gmic_mp_name(ind,out_str,siz,&mp.listout,(T)0)
+  return ::gmic_mp_name(ind,out_str,siz,&mp.imglist,(T)0)
 
 template<typename T>
 inline double gmic_mp_run(char *const str,
                           void *const p_list, const T& pixel_type);
 #define cimg_mp_func_run(str) \
-  return ::gmic_mp_run(str,&mp.listout,(T)0)
+  return ::gmic_mp_run(str,&mp.imglist,(T)0)
 
 template<typename Ts, typename T>
 inline double gmic_mp_store(const Ts *const ptr, const unsigned int siz,
@@ -236,7 +244,7 @@ inline double gmic_mp_store(const Ts *const ptr, const unsigned int siz,
                             const bool is_compressed, const char *const str,
                             void *const p_list, const T& pixel_type);
 #define cimg_mp_func_store(ptr,siz,w,h,d,s,is_compressed,str) \
-  return ::gmic_mp_store(ptr,siz,w,h,d,s,is_compressed,str,&mp.listout,(T)0)
+  return ::gmic_mp_store(ptr,siz,w,h,d,s,is_compressed,str,&mp.imglist,(T)0)
 
 #ifndef cimg_display
 #define cimg_display 0
@@ -257,12 +265,7 @@ inline double gmic_mp_store(const Ts *const ptr, const unsigned int siz,
 #include <signal.h>
 
 #endif // #if cimg_OS==2
-
-// Define some special character codes used for replacement in double quoted strings.
-const char gmic_dollar = 23, gmic_lbrace = 24, gmic_rbrace = 25, gmic_comma = 26, gmic_dquote = 28,
-  gmic_store = 29; // <- this one is only used in variable names.
-
-#endif // #ifndef gmic_build
+#endif // #ifndef gmic_core
 
 // Define main libgmic class 'gmic'.
 //----------------------------------
@@ -351,16 +354,18 @@ struct gmic {
   gmic_image<char> get_variable(const char *const name,
                                 const unsigned int *const variables_sizes=0,
                                 const gmic_list<char> *const images_names=0) const;
-  const char *set_variable(const char *const name, const char *const value,
-                           const char operation='=',
+  const char *set_variable(const char *const name, const char operation='=',
+                           const char *const value=0, const double *const pvalue=0,
                            const unsigned int *const variables_sizes=0);
   const char *set_variable(const char *const name, const gmic_image<unsigned char>& value,
                            const unsigned int *const variables_sizes=0);
 
   gmic& add_commands(const char *const data_commands, const char *const commands_file=0,
+                     const bool add_debug_info=false,
                      unsigned int *count_new=0, unsigned int *count_replaced=0,
                      bool *const is_entrypoint=0);
   gmic& add_commands(std::FILE *const file, const char *const filename=0,
+                     const bool add_debug_info=false,
                      unsigned int *count_new=0, unsigned int *count_replaced=0,
                      bool *const is_entrypoint=0);
 
